package com.glxp.udidl.admin.controller.collect;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.thread.ThreadUtil;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageInfo;
import com.glxp.udidl.admin.entity.collect.ThirdAliDrug;
import com.glxp.udidl.admin.enums.ResultEnum;
import com.glxp.udidl.admin.exception.JsonException;
import com.glxp.udidl.admin.req.alihealth.AlihealthKytDrugrescodeReqeust;
import com.glxp.udidl.admin.req.alihealth.local.AlihealthThirdAliDrugInsertReqeust;
import com.glxp.udidl.admin.req.collect.ThirdAliDrugAddRequest;
import com.glxp.udidl.admin.req.collect.ThirdAliDrugRequest;
import com.glxp.udidl.admin.res.BaseResponse;
import com.glxp.udidl.admin.res.PageSimpleResponse;
import com.glxp.udidl.admin.service.collect.ThirdAliDrugService;
import com.glxp.udidl.admin.util.ResultVOUtils;
import com.glxp.udidl.admin.util.alihealth.AlihealthUtils;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.ArrayList;
import java.util.List;

@RestController
@Slf4j
public class ThirdAliDrugController {

    @Resource
    private ThirdAliDrugService thirdAliDrugService;

    @PostMapping("/udiwms/aliDrug/addThirdAliDrug")
        public BaseResponse addThirdAliDrug(@RequestBody @Valid ThirdAliDrugAddRequest relCodeBatchRequest, BindingResult bindingResult) {
        thirdAliDrugService.addThirdAliDrug(relCodeBatchRequest);
        return ResultVOUtils.success("添加成功！");
        }
    @Resource
    private AlihealthUtils alihealthUtils;
    @GetMapping("/udiwms/aliDrug/getDrugLevelList")
    public BaseResponse getDrugLevelList(ThirdAliDrugRequest thirdAliDrug, BindingResult bindingResult) {
        if (bindingResult.hasErrors()) {
            return ResultVOUtils.error(ResultEnum.DATA_REPEAT, bindingResult.getFieldError().getDefaultMessage());
        }


        if (StrUtil.isEmpty(thirdAliDrug.getApprovalNum()) && StrUtil.isEmpty(thirdAliDrug.getNameCode()) &&
                StrUtil.isEmpty(thirdAliDrug.getCpmctymc())&&
                StrUtil.isEmpty(thirdAliDrug.getManufacturer())&&
                StrUtil.isEmpty(thirdAliDrug.getFormSpec())&&
                StrUtil.isEmpty(thirdAliDrug.getBzgg())
        ) {
            return ResultVOUtils.success("查询参数不能为空");
        }
        List<ThirdAliDrug> list = thirdAliDrugService.filterList(thirdAliDrug);
        if (CollUtil.isEmpty(list)){
            ThirdAliDrugAddRequest thirdAliDrugAddRequest = new ThirdAliDrugAddRequest();
            AlihealthThirdAliDrugInsertReqeust request  = new AlihealthThirdAliDrugInsertReqeust();
            AlihealthKytDrugrescodeReqeust alihealthKytDrugrescodeReqeust = new AlihealthKytDrugrescodeReqeust();
            alihealthKytDrugrescodeReqeust.setPhysic_name(thirdAliDrug.getCpmctymc());
            alihealthKytDrugrescodeReqeust.setApproval_licence_no(thirdAliDrug.getApprovalNum());
            alihealthKytDrugrescodeReqeust.setEnt_name(thirdAliDrug.getManufacturer());
            alihealthKytDrugrescodeReqeust.setPackage_spec(thirdAliDrug.getBzgg());
            alihealthKytDrugrescodeReqeust.setPrepn_spec(thirdAliDrug.getFormSpec());

            request.setAlihealthKytDrugrescodeReqeust(alihealthKytDrugrescodeReqeust);
            try {
                BaseResponse<List<ThirdAliDrug>> baseResponse = alihealthUtils.thirdAliDrugInsertAll(request);
                if(baseResponse.getCode() == 20000){
                    list = baseResponse.getData();
                }else {
                    log.error("阿里访问失败==="+baseResponse.getMessage());
                }
            }catch (Exception e){
                log.error("阿里访问失败==="+e.getMessage());
            }
            List<ThirdAliDrug> finalList = list;
            ThreadUtil.execAsync(() -> {
                try {
                    thirdAliDrugAddRequest.setList(finalList);
                    thirdAliDrugService.addThirdAliDrug(thirdAliDrugAddRequest);
                } catch (Exception e) {
                    log.error("异步更新阿里药品数据错误==="+e.getMessage());
                }
            });


        }
        PageInfo<ThirdAliDrug> pageInfo = new PageInfo<>(list);
        PageSimpleResponse<ThirdAliDrug> pageSimpleResponse = new PageSimpleResponse<>();
        pageSimpleResponse.setTotal(pageInfo.getTotal());
        pageSimpleResponse.setList(list);
        return ResultVOUtils.success(pageSimpleResponse);
    }

    @GetMapping("/udiwms/aliDrug/getDrugLevelListBycode")
    public BaseResponse getDrugLevelListBycode(ThirdAliDrugRequest thirdAliDrug, BindingResult bindingResult) {
        String nameCode = thirdAliDrug.getNameCode();
        if (StrUtil.isEmpty(nameCode)) {
            return ResultVOUtils.error(ResultEnum.DATA_REPEAT,"标识参数不能为空");
        }
        ThirdAliDrug one = thirdAliDrugService.getOne(new LambdaQueryWrapper<ThirdAliDrug>().eq(ThirdAliDrug::getNameCode, nameCode));
        if (one == null) {
            return ResultVOUtils.error(ResultEnum.DATA_REPEAT,"标识参数错误");
        }

        List<ThirdAliDrug> list = thirdAliDrugService.list(new LambdaQueryWrapper<ThirdAliDrug>()
                .eq(ThirdAliDrug::getApprovalNum, one.getApprovalNum())
                .eq(ThirdAliDrug::getCpmctymc, one.getCpmctymc())
                .eq(ThirdAliDrug::getForm, one.getForm())
                .eq(ThirdAliDrug::getBzgg, one.getBzgg())
                .eq(ThirdAliDrug::getPackRatio, one.getPackRatio()));

        return ResultVOUtils.success(list);
    }



    @PostMapping("/udiwms/aliDrug/optThirdAliDrug")
    public BaseResponse optThirdAliDrug(@RequestBody @Valid ThirdAliDrugRequest thirdAliDrugRequest, BindingResult bindingResult) {
        if (StrUtil.isEmpty(thirdAliDrugRequest.getNameCode())) {
            return ResultVOUtils.error(ResultEnum.DATA_REPEAT,"标识参数不能为空");
        }
        ThirdAliDrug thirdAliDrugServiceOne = thirdAliDrugService.getOne(
                new QueryWrapper<ThirdAliDrug>().eq("nameCode", thirdAliDrugRequest.getNameCode()).last("limit 1")
        );
        String str = "";
        List<ThirdAliDrug> thirdAliDrugList = new ArrayList<>();
        if (thirdAliDrugServiceOne != null) {
             thirdAliDrugList = thirdAliDrugService.list(
                    new QueryWrapper<ThirdAliDrug>().eq(StringUtils.isNotBlank(thirdAliDrugServiceOne.getBzgg()), "bzgg", thirdAliDrugServiceOne.getBzgg())
                            .eq(StringUtils.isNotBlank(thirdAliDrugServiceOne.getPackRatio()), "packRatio", thirdAliDrugServiceOne.getPackRatio())
                            .like(StringUtils.isNotBlank(thirdAliDrugRequest.getCpmctymc()), "cpmctymc", thirdAliDrugRequest.getCpmctymc())
                            .like(StringUtils.isNotBlank(thirdAliDrugRequest.getManufacturer()), "manufacturer", thirdAliDrugRequest.getManufacturer())
                            .like(StringUtils.isNotBlank(thirdAliDrugRequest.getApprovalNum()), "approvalNum", thirdAliDrugRequest.getApprovalNum())
                            .like(StringUtils.isNotBlank(thirdAliDrugRequest.getFormSpec()), "formSpec", thirdAliDrugRequest.getFormSpec())
                            .like(StringUtils.isNotBlank(thirdAliDrugRequest.getBzgg()), "bzgg", thirdAliDrugRequest.getBzgg())

            );
        }
        return ResultVOUtils.success(thirdAliDrugList);
    }

    @GetMapping("/udiwms/aliDrug/updateByCpmctymc")
    public BaseResponse updateByCpmctymc(ThirdAliDrugRequest thirdAliDrug, BindingResult bindingResult){
        String cpmctymc = thirdAliDrug.getCpmctymc();
        if (StrUtil.isEmpty(cpmctymc)) {
            return ResultVOUtils.error(ResultEnum.DATA_REPEAT,"标识参数不能为空");
        }
        List<ThirdAliDrug> add = thirdAliDrugService.updateByCpmctymc(cpmctymc);
        return ResultVOUtils.success(add);
    }


    @GetMapping("/udiwms/aliDrug/updateAll")
    public BaseResponse updateAll() {
        thirdAliDrugService.updateThirdAliDrugTask();
        return ResultVOUtils.success();
    }
}
