package com.glxp.udidl.admin.service.tyapi;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollUtil;
import com.alibaba.fastjson2.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.github.pagehelper.PageHelper;
import com.glxp.udidl.admin.entity.tyapi.TyContactCallEntity;
import com.glxp.udidl.admin.entity.tyapi.TyContactInfoEntity;
import com.glxp.udidl.admin.entity.tyapi.TySupplierEntity;
import com.glxp.udidl.admin.req.tyapi.TyBaseInfoRequest;
import com.glxp.udidl.admin.req.tyapi.TyImportSupRequest;
import com.glxp.udidl.admin.res.tyapi.CompanyBaseResponse;
import com.glxp.udidl.admin.res.tyapi.ContactResponse;
import com.glxp.udidl.admin.util.BeanCopyUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.glxp.udidl.admin.dao.tyapi.TyCompanyDetailMapper;
import com.glxp.udidl.admin.entity.tyapi.TyCompanyDetailEntity;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;

@Service
public class TyCompanyDetailService extends ServiceImpl<TyCompanyDetailMapper, TyCompanyDetailEntity> {


    @Resource
    TyDlHttpClient tyDlHttpClient;
    @Resource
    TyCompanyDetailMapper tyCompanyDetailMapper;

    public TyCompanyDetailEntity downloadByName(String company) {
        if (tyCompanyDetailMapper.exists(new QueryWrapper<TyCompanyDetailEntity>().eq("name", company))) {
            log.error(company + "企业详细信息已存在！");
        } else {
            CompanyBaseResponse companyBaseResponse = tyDlHttpClient.getBaseInfo(company);
            if (companyBaseResponse.getErrorCode() == 0) {
                CompanyBaseResponse.ResultDTO resultDTO = companyBaseResponse.getResult();
                TyCompanyDetailEntity tyCompanyDetailEntity = new TyCompanyDetailEntity();
                BeanUtil.copyProperties(resultDTO, tyCompanyDetailEntity);
                if (CollUtil.isNotEmpty(resultDTO.getHistoryNameList())) {
                    tyCompanyDetailEntity.setHistoryNameList(StringUtils.join(resultDTO.getHistoryNameList(), ","));
                }
                CompanyBaseResponse.ResultDTO.IndustryAllDTO industryAllDTO = resultDTO.getIndustryAll();
                if (industryAllDTO != null) {
                    tyCompanyDetailEntity.setIndustryAll(JSON.toJSONString(industryAllDTO));
                }
                tyCompanyDetailMapper.insert(tyCompanyDetailEntity);
            } else {
                log.error(company + "下载企业信息失败！");
            }
        }
        List<TyCompanyDetailEntity> tyCompanyDetailEntities = tyCompanyDetailMapper.selectList(new QueryWrapper<TyCompanyDetailEntity>().eq("name", company));
        if (CollUtil.isNotEmpty(tyCompanyDetailEntities))
            return tyCompanyDetailEntities.get(0);
        else
            return null;
    }

    public TyCompanyDetailEntity downloadByCode(String creditCode) {
        if (tyCompanyDetailMapper.exists(new QueryWrapper<TyCompanyDetailEntity>().eq("creditCode", creditCode))) {
            log.error(creditCode + "企业详细信息已存在！");
        } else {
            CompanyBaseResponse companyBaseResponse = tyDlHttpClient.getBaseInfo(creditCode);
            if (companyBaseResponse.getErrorCode() == 0) {
                CompanyBaseResponse.ResultDTO resultDTO = companyBaseResponse.getResult();
                TyCompanyDetailEntity tyCompanyDetailEntity = new TyCompanyDetailEntity();
                BeanUtil.copyProperties(resultDTO, tyCompanyDetailEntity);
                if (CollUtil.isNotEmpty(resultDTO.getHistoryNameList())) {
                    tyCompanyDetailEntity.setHistoryNameList(StringUtils.join(resultDTO.getHistoryNameList(), ","));
                }
                CompanyBaseResponse.ResultDTO.IndustryAllDTO industryAllDTO = resultDTO.getIndustryAll();
                if (industryAllDTO != null) {
                    tyCompanyDetailEntity.setIndustryAll(JSON.toJSONString(industryAllDTO));
                }
                tyCompanyDetailMapper.insert(tyCompanyDetailEntity);
            } else {
                log.error(creditCode + "下载企业信息失败！");
            }
        }
        List<TyCompanyDetailEntity> tyCompanyDetailEntities = tyCompanyDetailMapper.selectList(new QueryWrapper<TyCompanyDetailEntity>().eq("creditCode", creditCode));
        if (CollUtil.isNotEmpty(tyCompanyDetailEntities))
            return tyCompanyDetailEntities.get(0);
        else
            return null;
    }


    public List<TyCompanyDetailEntity> filterList(TyBaseInfoRequest tyBaseInfoRequest) {
        if (null == tyBaseInfoRequest) {
            return Collections.emptyList();
        }
        if (null != tyBaseInfoRequest.getPage() && null != tyBaseInfoRequest.getLimit()) {
            PageHelper.offsetPage((tyBaseInfoRequest.getPage() - 1) * tyBaseInfoRequest.getLimit(), tyBaseInfoRequest.getLimit());
        }
        return tyCompanyDetailMapper.filterList(tyBaseInfoRequest);
    }

}
